chat_ui/models/ai_chat_config library

Classes

AiChatConfig
Configuration class for customizing the AI chat interface.
LoadingConfig
Configuration class for loading states in the chat UI.
PaginationConfig
Configuration for pagination in the chat UI.
ScrollBehaviorConfig
Configuration for scroll behavior in the chat.

Enums

AutoScrollBehavior
Defines when the chat should automatically scroll to the bottom