exampleQuestions property
List of example questions to show in the welcome message.
Implementation
final List<ExampleQuestion> exampleQuestions;
List of example questions to show in the welcome message.
final List<ExampleQuestion> exampleQuestions;