scrollToFirstResponseMessage property
Whether to scroll to the first message of a response instead of the last message.
When set to true, after an AI response completes, the widget will scroll to show the first message of the response rather than scrolling all the way to the bottom. This is useful for long responses where users might want to read from the beginning.
Implementation
final bool scrollToFirstResponseMessage;