ChatUser class

Represents a user in the chat.

Constructors

ChatUser({required String id, String? name, String? firstName, String? avatar, Map<String, dynamic>? customProperties, String? role})
const

Properties

avatar String?
Optional URL to the user's avatar image
final
customProperties Map<String, dynamic>?
Optional custom properties for the user
final
hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier for the user
final
name String
Display name of the user
final
role String?
Optional role of the user (e.g., 'admin', 'user', 'bot')
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, String? name, String? firstName, String? avatar, Map<String, dynamic>? customProperties, String? role}) ChatUser
Creates a copy of this user with the given fields replaced with new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override