ChatExample class

Example chat messages for demonstration purposes.

Constructors

ChatExample({required String question, required void onTap(ChatMessagesController)})
Creates a chat example.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
onTap → void Function(ChatMessagesController)
Callback when the example is tapped.
final
question → String
The example question text.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited