QuickReplyOptions class

Options for customizing quick replies

Constructors

QuickReplyOptions({List<String>? quickReplies, void onQuickReplyTap(String)?, BoxDecoration? decoration, TextStyle? textStyle})
const

Properties

decoration BoxDecoration?
Decoration for quick reply buttons
final
hashCode int
The hash code for this object.
no setterinherited
onQuickReplyTap → void Function(String)?
Callback when a quick reply is tapped
final
quickReplies List<String>?
List of quick reply options
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
Text style for quick reply buttons
final

Methods

copyWith({List<String>? quickReplies, void onQuickReplyTap(String)?, BoxDecoration? decoration, TextStyle? textStyle}) QuickReplyOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited