chat_ui/models/chat/models library

Classes

BubbleStyle
Class for customizing chat bubble appearance
ChatMedia
Represents a media attachment in a chat message.
ChatMessage
Represents a message in the chat.
ChatUser
Represents a user in the chat.
MessageListOptions
Options for customizing the message list
MessageOptions
Options for customizing message appearance and behavior
MessageReaction
Represents a reaction to a chat message.
QuickReply
A model representing a quick reply option in the chat.
QuickReplyOptions
Options for customizing quick replies
ScrollToBottomOptions
Options for customizing scroll to bottom button

Enums

ChatMediaType
Enum representing different types of media in chat messages.