QuickReply class
A model representing a quick reply option in the chat.
Constructors
Properties
-
customProperties
→ Map<
String, dynamic> ? -
Optional custom data associated with this quick reply
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageText → String?
-
Optional message text to be sent when tapped
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
The title/text of the quick reply
final
- value → String?
-
Optional value different from title
final
Methods
-
copyWith(
{String? title, String? value, String? messageText, Map< String, dynamic> ? customProperties}) → QuickReply - Creates a copy of this quick reply with the given fields replaced with new values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited