ChatRecipe class

Constructors

ChatRecipe({required String imageUrl, required String? name, required String? id, required String? deviceModelIds, required String? langDesc})
const
ChatRecipe.fromJson(Map<String, dynamic> json)
factory

Properties

deviceModelIds String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
imageUrl String
final
langDesc String?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? imageUrl, String? name, String? id, String? deviceModelIds, String? langDesc}) ChatRecipe
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited