ExampleQuestionConfig class

Configuration for individual example questions in the chat

Constructors

ExampleQuestionConfig({BoxDecoration? containerDecoration, EdgeInsets containerPadding = const EdgeInsets.symmetric(vertical: 14, horizontal: 16), TextStyle? textStyle, IconData iconData = Icons.chat_bubble_outline_rounded, double iconSize = 20.0, Color? iconColor, IconData? trailingIconData = Icons.arrow_forward_rounded, double trailingIconSize = 20.0, Color? trailingIconColor, double spacing = 12.0, void onTap(String question)?})
const

Properties

containerDecoration → BoxDecoration?
Decoration for the question container
final
containerPadding → EdgeInsets
Padding for the question container
final
hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
Color of the leading icon
final
iconData → IconData
Icon data for the leading icon
final
iconSize → double
Size of the leading icon
final
onTap → void Function(String question)?
Custom onTap callback for the question
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
Spacing between elements
final
textStyle → TextStyle?
Style for the question text
final
trailingIconColor → Color?
Color of the trailing icon
final
trailingIconData → IconData?
Icon data for the trailing icon Made nullable to avoid analyzer warnings
final
trailingIconSize → double
Size of the trailing icon
final

Methods

copyWith({BoxDecoration? containerDecoration, EdgeInsets? containerPadding, TextStyle? textStyle, IconData? iconData, double? iconSize, Color? iconColor, IconData? trailingIconData, double? trailingIconSize, Color? trailingIconColor, double? spacing, void onTap(String question)?}) → ExampleQuestionConfig
Creates a copy of this config with the given fields replaced with new values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited