useOuterMaterial property
Whether to use a Material widget for the outer container. If false, no Material widget will be used at all, removing all elevation, color and shadow effects completely.
Implementation
final bool useOuterMaterial;
Whether to use a Material widget for the outer container. If false, no Material widget will be used at all, removing all elevation, color and shadow effects completely.
final bool useOuterMaterial;