ChatProvider class

Mixed-in types

Constructors

ChatProvider()

Properties

currentSessionId String
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
messages List<ChatMessage>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showWelcomeMessage bool
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
getMessagesForSession(String sessionId) List<ChatMessage>
handleExampleQuestionTap(String question) → void
handleExampleQuestionTapWithResponse(String question, Future<String> onAiResponse(String)) Future<void>
handleSend(ChatMessage message, Future<String> onAiResponse(String)) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
startNewSession() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited