CustomThemeExtension class

Inheritance
Annotations

Constructors

CustomThemeExtension({Color? chatBackground, Color? messageBubbleColor, Color? userBubbleColor, Color? messageTextColor, Color? inputBackgroundColor, Color? inputBorderColor, Color? inputTextColor, Color? hintTextColor, Color? backToBottomButtonColor, Color? sendButtonColor, Color? sendButtonIconColor})
const

Properties

backToBottomButtonColor Color?
final
chatBackground Color?
final
hashCode int
The hash code for this object.
no setterinherited
hintTextColor Color?
final
inputBackgroundColor Color?
final
inputBorderColor Color?
final
inputTextColor Color?
final
messageBubbleColor Color?
final
messageTextColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendButtonColor Color?
final
sendButtonIconColor Color?
final
type Object
The extension's type.
no setterinherited
userBubbleColor Color?
final

Methods

copyWith({Color? chatBackground, Color? messageBubbleColor, Color? userBubbleColor, Color? messageTextColor, Color? inputBackgroundColor, Color? inputBorderColor, Color? inputTextColor, Color? hintTextColor, Color? backToBottomButtonColor, Color? sendButtonColor, Color? sendButtonIconColor}) CustomThemeExtension
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<CustomThemeExtension>? other, double t) CustomThemeExtension
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited