chat_ui/widgets/loading_widget library

Classes

LoadingWidget
A highly customizable loading widget that displays a shimmer effect with animated text.

Enums

GradientType
Type of gradient to apply to the loading indicator background.