alignment property
Alignment of the text within the container. If null, aligns based on the text direction (start alignment).
Implementation
final Alignment? alignment;
Alignment of the text within the container. If null, aligns based on the text direction (start alignment).
final Alignment? alignment;