AutoScrollBehavior enum
Defines when the chat should automatically scroll to the bottom
Values
- always → const AutoScrollBehavior
-
Always scroll to the bottom when messages are added or updated. This is the most aggressive scrolling behavior but ensures all new content is visible.
- onNewMessage → const AutoScrollBehavior
-
Only scroll to the bottom when a new message is added (not during updates). This gives more control to the user during streaming messages, but ensures the user sees new messages when they are completed.
- onUserMessageOnly → const AutoScrollBehavior
-
Only scroll when the user sends a message (not for AI responses). This gives users full control over scrolling when viewing AI responses, which is useful for long responses that they want to read from the beginning.
- never → const AutoScrollBehavior
-
Never automatically scroll. The user is fully responsible for scrolling the chat view.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AutoScrollBehavior> - A constant List of the values in this enum, in order of their declaration.