LoadingConfig class
Configuration class for loading states in the chat UI.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool
-
Whether the chat is currently in a loading state
final
- loadingIndicator → Widget?
-
Custom loading indicator widget
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCenteredIndicator → bool
-
Whether to show the loading indicator centered in the chat
final
- typingIndicatorColor → Color?
-
Color for the typing indicator
final
- typingIndicatorSize → double?
-
Size of the typing indicator
final
Methods
-
copyWith(
{bool? isLoading, Widget? loadingIndicator, Color? typingIndicatorColor, double? typingIndicatorSize, bool? showCenteredIndicator}) → LoadingConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited