ChatMessage class
Constructors
Properties
- createdAt → DateTime
-
final
-
customProperties
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMarkdown → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
- user → ChatUser
-
final
Methods
-
copyWith(
{String? text, ChatUser? user, DateTime? createdAt, bool? isMarkdown, Map< String, dynamic> ? customProperties}) → ChatMessage - Creates a copy of this message with the given fields replaced with new values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited