BubbleStyle class
Class for customizing chat bubble appearance
Constructors
- BubbleStyle({double? userBubbleMaxWidth, double? aiBubbleMaxWidth, double? userBubbleMinWidth, double? aiBubbleMinWidth, Color? userBubbleColor, Color? aiBubbleColor, Color? userNameColor, Color? aiNameColor, Color? copyIconColor, double? userBubbleTopLeftRadius, double? userBubbleTopRightRadius, double? aiBubbleTopLeftRadius, double? aiBubbleTopRightRadius, double? bottomLeftRadius, double? bottomRightRadius, bool enableShadow = true, double? shadowOpacity, double? shadowBlurRadius, Offset? shadowOffset})
-
const
Properties
- aiBubbleColor → Color?
-
Background color for AI message bubbles
final
- aiBubbleMaxWidth → double?
-
Max width for AI message bubbles
final
- aiBubbleMinWidth → double?
-
Min width for AI message bubbles
final
- aiBubbleTopLeftRadius → double?
-
Top left radius for AI message bubbles
final
- aiBubbleTopRightRadius → double?
-
Top right radius for AI message bubbles
final
- aiNameColor → Color?
-
Color for AI name in AI bubbles
final
- bottomLeftRadius → double?
-
Bottom left radius for all message bubbles
final
- bottomRightRadius → double?
-
Bottom right radius for all message bubbles
final
- copyIconColor → Color?
-
Color for the copy icon
final
- enableShadow → bool
-
Whether to show shadow for message bubbles
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowBlurRadius → double?
-
Shadow blur radius for message bubbles
final
- shadowOffset → Offset?
-
Shadow offset for message bubbles
final
- shadowOpacity → double?
-
Shadow opacity for message bubbles
final
- userBubbleColor → Color?
-
Background color for user message bubbles
final
- userBubbleMaxWidth → double?
-
Max width for user message bubbles
final
- userBubbleMinWidth → double?
-
Min width for user message bubbles
final
- userBubbleTopLeftRadius → double?
-
Top left radius for user message bubbles
final
- userBubbleTopRightRadius → double?
-
Top right radius for user message bubbles
final
- userNameColor → Color?
-
Color for user name in user bubbles
final
Methods
-
copyWith(
{double? userBubbleMaxWidth, double? aiBubbleMaxWidth, double? userBubbleMinWidth, double? aiBubbleMinWidth, Color? userBubbleColor, Color? aiBubbleColor, Color? userNameColor, Color? aiNameColor, Color? copyIconColor, double? userBubbleTopLeftRadius, double? userBubbleTopRightRadius, double? aiBubbleTopLeftRadius, double? aiBubbleTopRightRadius, double? bottomLeftRadius, double? bottomRightRadius, bool? enableShadow, double? shadowOpacity, double? shadowBlurRadius, Offset? shadowOffset}) → BubbleStyle - Creates a copy of this BubbleStyle with the given fields replaced
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultStyle → const BubbleStyle
- Default style for message bubbles