MessageListOptions class
Options for customizing the message list
Constructors
-
MessageListOptions({ScrollController? scrollController, ScrollPhysics? scrollPhysics, Widget dateSeparatorBuilder(DateTime)?, Widget? loadingWidget, Future<
void> onLoadEarlier()?, PaginationConfig paginationConfig = const PaginationConfig(), bool isLoadingMore = false, bool hasMoreMessages = true, Future<void> onLoadMore()?}) -
const
Properties
- dateSeparatorBuilder → Widget Function(DateTime)?
-
Builder for date separator between messages
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMoreMessages → bool
-
Whether there are more messages to load
final
- isLoadingMore → bool
-
Whether more messages are currently loading
final
- loadingWidget → Widget?
-
Widget to show while loading more messages
final
-
onLoadEarlier
→ Future<
void> Function()? -
Callback when loading earlier messages via button
final
-
onLoadMore
→ Future<
void> Function()? -
Callback when automatic loading more messages is triggered by scroll
final
- paginationConfig → PaginationConfig
-
Pagination configuration for message loading
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
Custom scroll controller for the message list
final
- scrollPhysics → ScrollPhysics?
-
Custom scroll physics for the message list
final
Methods
-
copyWith(
{ScrollController? scrollController, ScrollPhysics? scrollPhysics, Widget dateSeparatorBuilder(DateTime)?, Widget? loadingWidget, Future< void> onLoadEarlier()?, PaginationConfig? paginationConfig, bool? isLoadingMore, bool? hasMoreMessages, Future<void> onLoadMore()?}) → MessageListOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited