ScrollToBottomOptions class
Options for customizing scroll to bottom button
This button allows users to quickly scroll to the most recent messages.
- In chronological mode (reverseOrder: false), it scrolls to the bottom of the list.
- In reverse mode (reverseOrder: true), it scrolls to the top of the list.
Constructors
- ScrollToBottomOptions({bool disabled = false, bool alwaysVisible = false, VoidCallback? onScrollToBottomPress, Widget scrollToBottomBuilder(ScrollController)?, double bottomOffset = 72, double rightOffset = 16, bool showText = false, String buttonText = 'Scroll to bottom'})
-
const
Properties
- alwaysVisible → bool
-
Whether to always show the scroll to bottom button
final
- bottomOffset → double
-
Distance from bottom of the screen (default is 72)
final
-
Custom text to display next to the icon (default is "Scroll to bottom")
final
- disabled → bool
-
Whether to disable the scroll to bottom button
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onScrollToBottomPress → VoidCallback?
-
Callback when scroll to bottom button is pressed
final
- rightOffset → double
-
Distance from right of the screen (default is 16)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollToBottomBuilder → Widget Function(ScrollController)?
-
Custom builder for scroll to bottom button
final
- showText → bool
-
Whether to show text next to the icon (default is true)
final
Methods
-
copyWith(
{bool? disabled, bool? alwaysVisible, VoidCallback? onScrollToBottomPress, Widget scrollToBottomBuilder(ScrollController)?, double? bottomOffset, double? rightOffset, bool? showText, String? buttonText}) → ScrollToBottomOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited