VoiceOptions class
Options for customizing the file upload functionality
Constructors
-
VoiceOptions({bool enabled = true, IconData? voiceIcon = Icons.mic, IconData? keyboardIcon = Icons.keyboard, Color? voiceIconColor, double? voiceIconSize = 24.0, String? tooltip = '', void onVoiceState(bool isVoice)?, int maxFilesPerMessage = 5, int maxFileSize = 10 * 1024 * 1024, List<
String> ? allowedFileTypes, Widget customUploadButtonBuilder(BuildContext, VoidCallback )?, bool confirmBeforeSend = false, String? uploadButtonText}) -
const
Properties
-
allowedFileTypes
→ List<
String> ? -
Allowed file types for upload
final
- confirmBeforeSend → bool
-
Whether to show a confirmation dialog before sending files
final
- customUploadButtonBuilder → Widget Function(BuildContext, VoidCallback )?
-
Custom builder for the upload button
final
- enabled → bool
-
Whether file uploading is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyboardIcon → IconData?
-
final
- maxFileSize → int
-
Maximum file size in bytes (defaults to 10MB)
final
- maxFilesPerMessage → int
-
Maximum number of files allowed in a single message
final
- onVoiceState → void Function(bool isVoice)?
-
Callback to be invoked when a file is selected
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltip → String?
-
Custom tooltip for the file upload button
final
- uploadButtonText → String?
-
Custom text for the upload button
final
- voiceIcon → IconData?
-
Custom icon for the file upload button
final
- voiceIconColor → Color?
-
Custom color for the file upload button
final
- voiceIconSize → double?
-
Custom size for the file upload button
final
Methods
-
copyWith(
{bool? enabled, IconData? voiceIcon, IconData? keyboardIcon, Color? voiceIconColor, double? voiceIconSize, String? tooltip, void onVoiceState(bool isVoice)?, int? maxFilesPerMessage, int? maxFileSize, List< String> ? allowedFileTypes, Widget customVoiceButtonBuilder(BuildContext, VoidCallback )?}) → VoiceOptions - Creates a copy of this FileUploadOptions with the given fields replaced with new values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited