WelcomeMessageConfig class
Configuration for the welcome message section of the chat
Constructors
- WelcomeMessageConfig({String? title, TextStyle? titleStyle, BoxDecoration? containerDecoration, EdgeInsets containerPadding = const EdgeInsets.all(24), EdgeInsets containerMargin = const EdgeInsets.symmetric(horizontal: 16, vertical: 12), String questionsSectionTitle = 'Here are some questions you can ask:', TextStyle? questionsSectionTitleStyle, BoxDecoration? questionsSectionDecoration, EdgeInsets questionsSectionPadding = const EdgeInsets.symmetric(horizontal: 12, vertical: 8), double questionSpacing = 12.0, Duration animation = const Duration(milliseconds: 500), Widget builder()?})
-
const
Properties
- animation → Duration
-
Duration for the welcome message animation
final
- builder → Widget Function()?
-
Custom builder function to create a welcome message widget
final
- containerDecoration → BoxDecoration?
-
Decoration for the main container
final
- containerMargin → EdgeInsets
-
Margin for the main container
final
- containerPadding → EdgeInsets
-
Padding for the main container
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- questionSpacing → double
-
Spacing between questions
final
- questionsSectionDecoration → BoxDecoration?
-
Decoration for the questions section container
final
- questionsSectionPadding → EdgeInsets
-
Padding for the questions section
final
- questionsSectionTitle → String
-
Title for the questions section
final
- questionsSectionTitleStyle → TextStyle?
-
Style for the questions section title
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
The title text of the welcome message
final
- titleStyle → TextStyle?
-
Style for the title text
final
Methods
-
copyWith(
{String? title, TextStyle? titleStyle, BoxDecoration? containerDecoration, EdgeInsets? containerPadding, EdgeInsets? containerMargin, String? questionsSectionTitle, TextStyle? questionsSectionTitleStyle, BoxDecoration? questionsSectionDecoration, EdgeInsets? questionsSectionPadding, double? questionSpacing, Duration? animation, Widget builder()?}) → WelcomeMessageConfig - Creates a copy of this config with the given fields replaced with new values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited