CustomThemeExtension class
Constructors
-
CustomThemeExtension({required Color chatBackground, required Color messageBubbleColor, required Color userBubbleColor, required Color messageTextColor, required Color inputBackgroundColor, required Color inputBorderColor, required Color inputTextColor, required Color hintTextColor, required Color backToBottomButtonColor, required Color sendButtonColor, required Color sendButtonIconColor, required Color typingIndicatorColor, required Color typingIndicatorDotColor, required Color messageTimeColor, required Color messageStatusColor, required Color messageDividerColor, required double elevation, required double borderRadius})
-
Methods
-
copyWith({Color? chatBackground, Color? messageBubbleColor, Color? userBubbleColor, Color? messageTextColor, Color? inputBackgroundColor, Color? inputBorderColor, Color? inputTextColor, Color? hintTextColor, Color? backToBottomButtonColor, Color? sendButtonColor, Color? sendButtonIconColor, Color? typingIndicatorColor, Color? typingIndicatorDotColor, Color? messageTimeColor, Color? messageStatusColor, Color? messageDividerColor, double? elevation, double? borderRadius})
→ ThemeExtension<CustomThemeExtension>
-
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(covariant ThemeExtension<CustomThemeExtension>? other, double t)
→ ThemeExtension<CustomThemeExtension>
-
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited