CustomChatWidget class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CustomChatWidget
Constructors
-
CustomChatWidget({Key? key, required ChatUser currentUser, required List<
ChatMessage> messages, required void onSend(ChatMessage), required MessageOptions messageOptions, InputOptions inputOptions = const InputOptions(), required List<ChatUser> ? typingUsers, required MessageListOptions messageListOptions, required bool readOnly, required QuickReplyOptions quickReplyOptions, required ScrollToBottomOptions scrollToBottomOptions, Widget? typingIndicator, ChatMessagesController? controller}) -
const
Properties
- controller → ChatMessagesController?
-
final
- currentUser → ChatUser
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputOptions → InputOptions
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- messageListOptions → MessageListOptions
-
final
- messageOptions → MessageOptions
-
final
-
messages
→ List<
ChatMessage> -
final
- onSend → void Function(ChatMessage)
-
final
- quickReplyOptions → QuickReplyOptions
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollToBottomOptions → ScrollToBottomOptions
-
final
- typingIndicator → Widget?
-
Custom widget to display instead of the default typing indicator
final
-
typingUsers
→ List<
ChatUser> ? -
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CustomChatWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited