ExtendedListDelegate class
Constructors
- ExtendedListDelegate({LastChildLayoutTypeBuilder? lastChildLayoutTypeBuilder, CollectGarbage? collectGarbage, ViewportBuilder? viewportBuilder, bool closeToTrailing = false})
-
const
Properties
- closeToTrailing → bool
-
final
- collectGarbage → CollectGarbage?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastChildLayoutTypeBuilder → LastChildLayoutTypeBuilder?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewportBuilder → ViewportBuilder?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited